@@ -2,8 +2,7 @@
     icmplib
     ~~~~~~~
 
-    A powerful library for forging ICMP packets and performing ping
-    and traceroute.
+    The power to forge ICMP packets and do ping and traceroute.
 
         https://github.com/ValentinBELYN/icmplib
 
@@ -27,17 +26,19 @@
     <https://www.gnu.org/licenses/>.
 '''
 
-from .sockets import ICMPv4Socket, ICMPv6Socket
+from .sockets import ICMPv4Socket, ICMPv6Socket, AsyncSocket
 from .models import ICMPRequest, ICMPReply, Host, Hop
-from .ping import ping, multiping
+from .ping import ping, async_ping
+from .multiping import multiping, async_multiping
 from .traceroute import traceroute
 from .exceptions import *
-from .utils import PID, resolve, is_ipv4_address, is_ipv6_address
+from .utils import is_hostname, is_ipv4_address, is_ipv6_address
+from .utils import PID, resolve, async_resolve
 
 
 __author__    = 'Valentin BELYN'
 __copyright__ = 'Copyright 2017-2021 Valentin BELYN'
 __license__   = 'GNU Lesser General Public License v3.0'
 
-__version__   = '2.0.2'
-__build__     = '210207'
+__version__   = '3.0.2'
+__build__     = '211031'
